Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Firewall Manager.

Actions, resources, and condition keys for AWS Firewall Manager - Service Authorization Reference

# Actions, resources, and condition keys for AWS Firewall Manager

AWS Firewall Manager (service prefix: `fms` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Firewall Manager
- Resource types defined by AWS Firewall Manager
- Condition keys for AWS Firewall Manager

## Actions defined by AWS Firewall Manager

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateAdminAccount | Grants permission to set the AWS Firewall Manager administrator account and enables the service in all organization accounts | Write |  |  |
AssociateThirdPartyFirewall | Grants permission to set the Firewall Manager administrator as a tenant administrator of a third-party firewall service | Write |  |  |
BatchAssociateResource | Grants permission to associate resources to an AWS Firewall Manager resource set | Write | resource-set* |  |
BatchDisassociateResource | Grants permission to disassociate resources from an AWS Firewall Manager resource set | Write | resource-set* |  |
DeleteAppsList | Grants permission to permanently deletes an AWS Firewall Manager applications list | Write | applications-list* |  |
DeleteNotificationChannel | Grants permission to delete an AWS Firewall Manager association with the IAM role and the Amazon Simple Notification Service (SNS) topic that is used to notify the FM administrator about major FM events and errors across the organization | Write |  |  |
DeletePolicy | Grants permission to permanently delete an AWS Firewall Manager policy | Write | policy* |  |
| aws:ResourceTag/${TagKey} |
DeleteProtocolsList | Grants permission to permanently deletes an AWS Firewall Manager protocols list | Write | protocols-list* |  |
DeleteResourceSet | Grants permission to permanently delete an AWS Firewall Manager resource set | Write | resource-set* |  |
| aws:ResourceTag/${TagKey} |
DisassociateAdminAccount | Grants permission to disassociate the account that has been set as the AWS Firewall Manager administrator account and and disables the service in all organization accounts | Write |  |  |
DisassociateThirdPartyFirewall | Grants permission to disassociate a Firewall Manager administrator from a third-party firewall tenant | Write |  |  |
GetAdminAccount | Grants permission to return the AWS Organizations account that is associated with AWS Firewall Manager as the AWS Firewall Manager administrator | Read |  |  |
GetAdminScope | Grants permission to return information about the specified account's administrative scope | Read |  |  |
GetAppsList | Grants permission to return information about the specified AWS Firewall Manager applications list | Read | applications-list* |  |
GetComplianceDetail | Grants permission to retrieve detailed compliance information about the specified member account. Details include resources that are in and out of compliance with the specified policy | Read | policy* |  |
GetNotificationChannel | Grants permission to retrieve information about the Amazon Simple Notification Service (SNS) topic that is used to record AWS Firewall Manager SNS logs | Read |  |  |
GetPolicy | Grants permission to retrieve information about the specified AWS Firewall Manager policy | Read | policy* |  |
GetProtectionStatus | Grants permission to retrieve policy-level attack summary information in the event of a potential DDoS attack | Read | policy* |  |
GetProtocolsList | Grants permission to return information about the specified AWS Firewall Manager protocols list | Read | protocols-list* |  |
GetResourceSet | Grants permission to retrieve information about the specified AWS Firewall Manager resource set | Read | resource-set* |  |
GetThirdPartyFirewallAssociationStatus | Grants permission to retrieve the onboarding status of a Firewall Manager administrator account to third-party firewall vendor tenant | Read |  |  |
GetViolationDetails | Grants permission to retrieve violations for a resource based on the specified AWS Firewall Manager policy and AWS account | Read | policy* |  |
ListAdminAccountsForOrganization | Grants permission to return a AdminAccounts object that lists the Firewall Manager administrators within the organization that are onboarded to Firewall Manager by AssociateAdminAccount | List |  |  |
ListAdminsManagingAccount | Grants permission to list the accounts that are managing the specified AWS Organizations member account | List |  |  |
ListAppsLists | Grants permission to return an array of AppsListDataSummary objects | List |  |  |
ListComplianceStatus | Grants permission to retrieve an array of PolicyComplianceStatus objects in the response. Use PolicyComplianceStatus to get a summary of which member accounts are protected by the specified policy | List | policy* |  |
ListDiscoveredResources | Grants permission to retrieve an array of resources in the organization's accounts that are available to be associated with a resource set | List |  |  |
ListMemberAccounts | Grants permission to retrieve an array of member account ids if the caller is FMS admin account | List |  |  |
ListPolicies | Grants permission to retrieve an array of PolicySummary objects in the response | List |  |  |
ListProtocolsLists | Grants permission to return an array of ProtocolsListDataSummary objects | List |  |  |
ListResourceSetResources | Grants permission to retrieve an array of resources that are currently associated to a resource set | List | resource-set* |  |
ListResourceSets | Grants permission to retrieve an array of ResourceSetSummary objects | List |  |  |
ListTagsForResource | Grants permission to list Tags for a given resource | Read | policy* |  |
ListThirdPartyFirewallFirewallPolicies | Grants permission to retrieve a list of all of the third-party firewall policies that are associated with the third-party firewall administrator's account | List |  |  |
PutAdminAccount | Grants permission to create or update an Firewall Manager administrator account | Write |  |  |
PutAppsList | Grants permission to create an AWS Firewall Manager applications list | Write | applications-list* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
PutNotificationChannel | Grants permission to designate the IAM role and Amazon Simple Notification Service (SNS) topic that AWS Firewall Manager (FM) could use to notify the FM administrator about major FM events and errors across the organization | Write |  |  |
PutPolicy | Grants permission to create an AWS Firewall Manager policy | Write | policy* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
PutProtocolsList | Grants permission to creates an AWS Firewall Manager protocols list | Write | protocols-list* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
PutResourceSet | Grants permission to create an AWS Firewall Manager resource set | Write | resource-set* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
TagResource | Grants permission to add a Tag to a given resource | Tagging | applications-list |  |
policy |  |
protocols-list |  |
resource-set |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove a Tag from a given resource | Tagging | applications-list |  |
policy |  |
protocols-list |  |
resource-set |  |
| aws:TagKeys |

## Resource types defined by AWS Firewall Manager

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
policy | `arn:$ { Partition}:fms:$ { Region}:$ { Account}:policy/$ { Id}` | aws:ResourceTag/${TagKey}
applications-list | `arn:$ { Partition}:fms:$ { Region}:$ { Account}:applications-list/$ { Id}` | aws:ResourceTag/${TagKey}
protocols-list | `arn:$ { Partition}:fms:$ { Region}:$ { Account}:protocols-list/$ { Id}` | aws:ResourceTag/${TagKey}
resource-set | `arn:$ { Partition}:fms:$ { Region}:$ { Account}:resource-set/$ { Id}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Firewall Manager

AWS Firewall Manager defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by the the presence of tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.